@@ -51,7 +51,7 @@ api_list = [
         False,
     ),  # Yandere and Konachan are forks of the same github repo. That's why they have almost-identical apis.
     ("Konachan", None, "https://konachan.com/help/api", False),
-    ("Waifu.im", None, "https://waifu.im/", False),
+    ("Waifu.im", apis.WaifuImAPI, "https://waifu.im/", True),
     ("Catboys", None, "https://catboys.com/api", False),
     (
         "Anime Character Database",
@@ -59,4 +59,14 @@ api_list = [
         "http://wiki.animecharactersdatabase.com/index.php?title=API_Access",
         False,
     ),
+    (
+        "Nekos API",
+        apis.NekosAPI,
+        "https://nekos.nekidev.com/docs/rest-api/endpoints",
+        True,
+    ),
 ]
+
+__version__ = '0.15.0'
+__authors__ = ['Nekidev <neki@nekidev.com>']
+__license__ = "MIT License"
